==> iam-0.13.0-sources.jar: software/amazon/awscdk/services/iam/User.java <==
package software.amazon.awscdk.services.iam;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-19T13:54:38.992Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.User")
public class User extends software.amazon.awscdk.Construct implements software.amazon.awscdk.services.iam.IIdentityResource,software.amazon.awscdk.services.iam.IPrincipal {
    protected User(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public User(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.iam.UserProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(props)).toArray());
    }
    public User(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    /**
     * Adds this user to a group.
     */
    public void addToGroup(final software.amazon.awscdk.services.iam.Group group) {
        this.jsiiCall("addToGroup", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(group, "group is required")).toArray());
    }

    /**
     * Adds an IAM statement to the default policy.
     */
    @Override
    public void addToPolicy(final software.amazon.awscdk.services.iam.PolicyStatement statement) {
        this.jsiiCall("addToPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(statement, "statement is required")).toArray());
    }

    /**
     * Attaches a policy to this user.
     */
    @Override
    public void attachInlinePolicy(final software.amazon.awscdk.services.iam.Policy policy) {
        this.jsiiCall("attachInlinePolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(policy, "policy is required")).toArray());
    }

    /**
     * Attaches a managed policy to the user.
     * @param arn The ARN of the managed policy to attach.
     */
    @Override
    public void attachManagedPolicy(final java.lang.String arn) {
        this.jsiiCall("attachManagedPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(arn, "arn is required")).toArray());
    }

    /**
     * Returns the ARN of this user.
     */
    @Override
    public software.amazon.awscdk.services.iam.PolicyPrincipal getPrincipal() {
        return this.jsiiGet("principal", software.amazon.awscdk.services.iam.PolicyPrincipal.class);
    }

    /**
     * An attribute that represents the user's ARN.
     */
    public java.lang.String getUserArn() {
        return this.jsiiGet("userArn", java.lang.String.class);
    }

    /**
     * An attribute that represents the user name.
     */
    public java.lang.String getUserName() {
        return this.jsiiGet("userName", java.lang.String.class);
    }
}

==> iam-0.14.1-sources.jar: software/amazon/awscdk/services/iam/User.java <==
package software.amazon.awscdk.services.iam;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.8 (build 100f5ad)", date = "2018-10-26T17:52:24.957Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.User")
public class User extends software.amazon.awscdk.Construct implements software.amazon.awscdk.services.iam.IPrincipal {
    protected User(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public User(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.iam.UserProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(props)).toArray());
    }
    public User(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    /**
     * Adds this user to a group.
     */
    public void addToGroup(final software.amazon.awscdk.services.iam.Group group) {
        this.jsiiCall("addToGroup", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(group, "group is required")).toArray());
    }

    /**
     * Adds an IAM statement to the default policy.
     */
    @Override
    public void addToPolicy(final software.amazon.awscdk.services.iam.PolicyStatement statement) {
        this.jsiiCall("addToPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(statement, "statement is required")).toArray());
    }

    /**
     * Attaches a policy to this user.
     */
    @Override
    public void attachInlinePolicy(final software.amazon.awscdk.services.iam.Policy policy) {
        this.jsiiCall("attachInlinePolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(policy, "policy is required")).toArray());
    }

    /**
     * Attaches a managed policy to the user.
     * @param arn The ARN of the managed policy to attach.
     */
    @Override
    public void attachManagedPolicy(final java.lang.String arn) {
        this.jsiiCall("attachManagedPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(arn, "arn is required")).toArray());
    }

    /**
     * Returns the ARN of this user.
     */
    @Override
    public software.amazon.awscdk.services.iam.PolicyPrincipal getPrincipal() {
        return this.jsiiGet("principal", software.amazon.awscdk.services.iam.PolicyPrincipal.class);
    }

    /**
     * An attribute that represents the user's ARN.
     */
    public java.lang.String getUserArn() {
        return this.jsiiGet("userArn", java.lang.String.class);
    }

    /**
     * An attribute that represents the user name.
     */
    public java.lang.String getUserName() {
        return this.jsiiGet("userName", java.lang.String.class);
    }
}
